@@ -1,5 +1,5 @@
 // libTorrent - BitTorrent library
-// Copyright (C) 2005-2007, Jari Sundell
+// Copyright (C) 2005-2011, Jari Sundell
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -48,14 +48,14 @@ namespace torrent {
 
 class LIBTORRENT_EXPORT Rate {
 public:
-  typedef int32_t                          timer_type;
-  typedef uint32_t                         rate_type;
-  typedef uint64_t                         total_type;
+  using timer_type = int32_t;
+  using rate_type  = uint64_t;
+  using total_type = uint64_t;
 
-  typedef std::pair<timer_type, rate_type> value_type;
-  typedef std::deque<value_type>           queue_type;
+  using value_type = std::pair<timer_type, rate_type>;
+  using queue_type = std::deque<value_type>;
 
-  Rate(timer_type span) : m_current(0), m_total(0), m_span(span) {}
+  Rate(timer_type span) :  m_span(span) {}
 
   // Bytes per second.
   rate_type           rate() const;
@@ -87,8 +87,8 @@ private:
 
   mutable queue_type  m_container;
 
-  mutable rate_type   m_current;
-  total_type          m_total;
+  mutable rate_type   m_current{0};
+  total_type          m_total{0};
   timer_type          m_span;
 };
 
